==> kubernetes-model-core-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/TopologySpreadConstraintBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TopologySpreadConstraintBuilder extends TopologySpreadConstraintFluentImpl<TopologySpreadConstraintBuilder> implements VisitableBuilder<TopologySpreadConstraint,TopologySpreadConstraintBuilder>{
  public TopologySpreadConstraintBuilder() {
    this(false);
  }
  public TopologySpreadConstraintBuilder(Boolean validationEnabled) {
    this(new TopologySpreadConstraint(), validationEnabled);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent) {
    this(fluent, false);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TopologySpreadConstraint(), validationEnabled);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent,TopologySpreadConstraint instance) {
    this(fluent, instance, false);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent,TopologySpreadConstraint instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLabelSelector(instance.getLabelSelector()); 
    fluent.withMaxSkew(instance.getMaxSkew()); 
    fluent.withMinDomains(instance.getMinDomains()); 
    fluent.withTopologyKey(instance.getTopologyKey()); 
    fluent.withWhenUnsatisfiable(instance.getWhenUnsatisfiable()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraint instance) {
    this(instance,false);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraint instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLabelSelector(instance.getLabelSelector()); 
    this.withMaxSkew(instance.getMaxSkew()); 
    this.withMinDomains(instance.getMinDomains()); 
    this.withTopologyKey(instance.getTopologyKey()); 
    this.withWhenUnsatisfiable(instance.getWhenUnsatisfiable()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  TopologySpreadConstraintFluent<?> fluent;
  Boolean validationEnabled;
  public TopologySpreadConstraint build() {
    TopologySpreadConstraint buildable = new TopologySpreadConstraint(fluent.getLabelSelector(),fluent.getMaxSkew(),fluent.getMinDomains(),fluent.getTopologyKey(),fluent.getWhenUnsatisfiable());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/TopologySpreadConstraintBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TopologySpreadConstraintBuilder extends TopologySpreadConstraintFluentImpl<TopologySpreadConstraintBuilder> implements VisitableBuilder<TopologySpreadConstraint,TopologySpreadConstraintBuilder>{
  public TopologySpreadConstraintBuilder() {
    this(false);
  }
  public TopologySpreadConstraintBuilder(Boolean validationEnabled) {
    this(new TopologySpreadConstraint(), validationEnabled);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent) {
    this(fluent, false);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TopologySpreadConstraint(), validationEnabled);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent,TopologySpreadConstraint instance) {
    this(fluent, instance, false);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraintFluent<?> fluent,TopologySpreadConstraint instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLabelSelector(instance.getLabelSelector()); 
    fluent.withMatchLabelKeys(instance.getMatchLabelKeys()); 
    fluent.withMaxSkew(instance.getMaxSkew()); 
    fluent.withMinDomains(instance.getMinDomains()); 
    fluent.withNodeAffinityPolicy(instance.getNodeAffinityPolicy()); 
    fluent.withNodeTaintsPolicy(instance.getNodeTaintsPolicy()); 
    fluent.withTopologyKey(instance.getTopologyKey()); 
    fluent.withWhenUnsatisfiable(instance.getWhenUnsatisfiable()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraint instance) {
    this(instance,false);
  }
  public TopologySpreadConstraintBuilder(TopologySpreadConstraint instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLabelSelector(instance.getLabelSelector()); 
    this.withMatchLabelKeys(instance.getMatchLabelKeys()); 
    this.withMaxSkew(instance.getMaxSkew()); 
    this.withMinDomains(instance.getMinDomains()); 
    this.withNodeAffinityPolicy(instance.getNodeAffinityPolicy()); 
    this.withNodeTaintsPolicy(instance.getNodeTaintsPolicy()); 
    this.withTopologyKey(instance.getTopologyKey()); 
    this.withWhenUnsatisfiable(instance.getWhenUnsatisfiable()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  TopologySpreadConstraintFluent<?> fluent;
  Boolean validationEnabled;
  public TopologySpreadConstraint build() {
    TopologySpreadConstraint buildable = new TopologySpreadConstraint(fluent.getLabelSelector(),fluent.getMatchLabelKeys(),fluent.getMaxSkew(),fluent.getMinDomains(),fluent.getNodeAffinityPolicy(),fluent.getNodeTaintsPolicy(),fluent.getTopologyKey(),fluent.getWhenUnsatisfiable());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
